@@ -29,7 +29,6 @@
 #include <QListView>
 #include <QLabel>
 #include <QTimer>
-#include <QDebug>
 #include <QIcon>
 
 #include <KMessageWidget>
@@ -74,7 +73,7 @@ QVariant DevicesProxyModel::data(const QModelIndex &index, int role) const
 {
     switch (role) {
     case Qt::DecorationRole:
-        return QIcon::fromTheme(index.data(BluezQt::DevicesModel::IconRole).toString());
+        return QIcon::fromTheme(index.data(BluezQt::DevicesModel::IconRole).toString(), QIcon::fromTheme(QStringLiteral("preferences-system-bluetooth")));
 
     default:
         return QSortFilterProxyModel::data(index, role);
